@@ -14,7 +14,7 @@
 #define QT_FEATURE_reduce_relocations -1
 #define QT_FEATURE_release_tools -1
 #define QT_FEATURE_sql 1
-#define QT_FEATURE_sse2 1
+#define QT_FEATURE_sse2 -1
 #define QT_FEATURE_stack_protector_strong -1
 #define QT_FEATURE_system_zlib 1
 #define QT_FEATURE_testlib 1
